@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -14,7 +17,10 @@ import cdktf._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@cdktf/tf-module-stack", "4.0.9", __name__[0:-6], "tf-module-stack@4.0.9.jsii.tgz"
+    "@cdktf/tf-module-stack",
+    "5.0.12",
+    __name__[0:-6],
+    "tf-module-stack@5.0.12.jsii.tgz",
 )
 
 __all__ = [
